@@ -1,4 +1,4 @@
-eiv <- function(L,  identity=seq(ncol(L)), ...){
+eiv <- function(L,  identity=seq(NCOL(L)), ...){
    A1 <- L[ identity, , drop=FALSE]
    g <- solve(A1)
    if(1e-14 < max(abs(diag(1, length(identity)) - A1 %*% g)))
@@ -6,7 +6,9 @@ eiv <- function(L,  identity=seq(ncol(L)), ...){
    B <- array(NA, dim(L))
    B[identity, ] <- diag(1, length(identity))
    B[-identity,] <- L[-identity,, drop=FALSE] %*% g
-   dimnames(B) <- list(dimnames(L)[[1]], paste("factor", seq(length(identity))))
-   list(loadings=B, Th=t(A1), method="eiv", orthogonal=FALSE, convergence=TRUE,
+   dimnames(B) <- list(dimnames(L)[[1]], paste("factor", seq(NCOL(L))))
+   r <- list(loadings=B, Th=t(A1), method="eiv", orthogonal=FALSE, convergence=TRUE,
         Phi= tcrossprod(A1))
-   }
+   class(r) <- "GPArotation"
+   r
+  }
